@@ -100,17 +100,18 @@
 #' @author Jeff Laake, Jon Bishop, David Borchers
 #' @keywords plot
 #' @examples
-#' 
+#' \donttest{
 #' data(book.tee.data)
 #' region<<-book.tee.data$book.tee.region
 #' egdata<<-book.tee.data$book.tee.dataframe
 #' samples<<-book.tee.data$book.tee.samples
 #' obs<<-book.tee.data$book.tee.obs
 #' xx=ddf(dsmodel = ~mcds(key = "hn", formula = ~sex), data = egdata[egdata$observer==1, ], method = "ds", meta.data = list(width = 4))
-#' plot(xx,breaks=c(0,.5,1,2,3,4),showpoints=FALSE)
-#' plot(xx,breaks=c(0,.5,1,2,3,4),subset=sex==0)
-#' plot(xx,breaks=c(0,.5,1,2,3,4),subset=sex==1)
-#' 
+#' par(mfrow=c(3,2))
+#' plot(xx,breaks=c(0,.5,1,2,3,4),showpoints=FALSE,new=FALSE)
+#' plot(xx,breaks=c(0,.5,1,2,3,4),subset=sex==0,new=FALSE)
+#' plot(xx,breaks=c(0,.5,1,2,3,4),subset=sex==1,new=FALSE)
+#' }
 plot.rem <- function(x, which=1:6, breaks=NULL, nc=NULL,  maintitle="", showlines=TRUE, showpoints=TRUE, 
 		ylim=c(0,1),angle=-45,density=20,col="black",jitter=NULL,divisions=25,new=TRUE, ...)
 {	
@@ -132,12 +133,12 @@ plot.rem <- function(x, which=1:6, breaks=NULL, nc=NULL,  maintitle="", showline
 	p0<-predict(model$mr,newdata=xmat.p0,integrate=FALSE)$fitted
 	xmat<-model$mr$data
 	cond.det<-predict(model$mr,newdata=xmat,integrate=FALSE)
-	detfct.pooled.values <- detfct(xmat$distance[xmat$observer==1],ddfobj)
+	width <- model$meta.data$width
+	left <- model$meta.data$left
+	detfct.pooled.values <- detfct(xmat$distance[xmat$observer==1],ddfobj,width=width-left)
 	delta<-cond.det$fitted/(p0*detfct.pooled.values)
 	p1<-cond.det$p1
 	p2<-cond.det$p2
-	width <- model$meta.data$width
-	left <- model$meta.data$left
 #
 #   If number of classes for histogram intervals was not set compute a reasonable default
 #
